@@ -33,34 +33,21 @@
 #define __GNC_TREE_VIEW_H
 
 #include <gtk/gtk.h>
-#include "gnc-cell-renderer-date.h"
 
 G_BEGIN_DECLS
 
 /* type macros */
 #define GNC_TYPE_TREE_VIEW            (gnc_tree_view_get_type ())
-#define GNC_TREE_VIEW(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNC_TYPE_TREE_VIEW, GncTreeView))
-#define GNC_TREE_VIEW_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GNC_TYPE_TREE_VIEW, GncTreeViewClass))
-#define GNC_IS_TREE_VIEW(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNC_TYPE_TREE_VIEW))
-#define GNC_IS_TREE_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNC_TYPE_TREE_VIEW))
-#define GNC_TREE_VIEW_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GNC_TYPE_TREE_VIEW, GncTreeViewClass))
+G_DECLARE_DERIVABLE_TYPE (GncTreeView, gnc_tree_view, GNC, TREE_VIEW, GtkTreeView)
+
 #define GNC_TREE_VIEW_NAME            "GncTreeView"
 
 
 /* typedefs & structures */
-typedef struct
-{
-    GtkTreeView gtk_tree_view;
-} GncTreeView;
-
-typedef struct
+struct _GncTreeViewClass
 {
     GtkTreeViewClass gtk_tree_view;
-} GncTreeViewClass;
-
-/* Standard g_object type */
-GType gnc_tree_view_get_type (void);
-
+};
 
 /* The columns managed by gnc-tree-view can use the following column
    attributes.  Set them with:
@@ -79,7 +66,7 @@ GType gnc_tree_view_get_type (void);
 #define REAL_TITLE  "real_title"
 
 /* The name of this column to use when saving the view's state.  It is
- * used internally to map this colum's properties to the saved state. */
+ * used internally to map this column's properties to the saved state. */
 #define PREF_NAME  "pref-name"
 
 /* A column with this attribute set cannot be hidden from view. Valid
@@ -199,31 +186,45 @@ gnc_tree_view_add_text_column (GncTreeView *view,
                                gint model_visibility_column,
                                GtkTreeIterCompareFunc column_sort_fn);
 
-/** This function adds a new combobox column to a GncTreeView base
- *  view.  The parameters it takes in common with
- *  gnc_tree_view_add_text_column() behave the same as there.  In
- *  addition, it will use combo_tree_model as the GtkTreeModel for the
- *  combobox, and combo_model_text_column will be the column in the
- *  model used for displaying the text in the combobox.
+/** This function adds a new text view column to a GncTreeView base view.
+ *  It takes all the parameters necessary to hook a GtkTreeModel
+ *  column to a GtkTreeViewColumn.
+ *
+ *  @param view A pointer to a generic GncTreeView.
+ *
+ *  @param column_title The title for this column.
+ *
+ *  @param pref_name The internal name of this column.  This name is
+ *  used in several functions to look up the column, and it is also
+ *  used when saving/restoring the view's state.
+ *
+ *  @param icon_name The name of the icon to display to
+ *  the left of the text in this column.  Used for adding icons like
+ *  the "account" icon to a view.  This must be a registered icon,
+ *  not a filename.
+ *
+ *  @param sizing_text A string used to compute the default width of
+ *  the column.  This text is never displayed.
+ *
+ *  @param model_data_column The index of the GtkTreeModel data column
+ *  used to determine the data that will be displayed in this column
+ *  for each row in the view.  Use GNC_TREE_VIEW_COLUMN_DATA_NONE if
+ *  you plan on using a non-model data source for this column.  This
+ *  index is connected to the "text" attribute of the cell renderer.
+ *
+ *  @param model_visibility_column The index of the GtkTreeModel data
+ *  column used to determine whether or not a checkbox for each row
+ *  will be displayed at all.  Use GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS
+ *  if the checkbox should be displayed in all rows.
+ *
+ *  @param column_sort_fn The function that GtkTreeModelSort
+ *  will call to compare two rows to determine their displayed
+ *  order.
+ *
+ *  @return The newly created GtkTreeViewColumn.
  */
 GtkTreeViewColumn *
-gnc_tree_view_add_combo_column (GncTreeView *view,
-                                const gchar *column_title,
-                                const gchar *pref_name,
-                                const gchar *sizing_text,
-                                gint model_data_column,
-                                gint model_visibility_column,
-                                GtkTreeModel *combo_tree_model,
-                                gint combo_model_text_column,
-                                GtkTreeIterCompareFunc column_sort_fn);
-
-
-/** This function adds a new date column to a GncTreeView base
- *  view.  The parameters it takes in common with
- *  gnc_tree_view_add_text_column() behave the same as there.
- */
-GtkTreeViewColumn *
-gnc_tree_view_add_date_column (GncTreeView *view,
+gnc_tree_view_add_text_view_column (GncTreeView *view,
                                const gchar *column_title,
                                const gchar *pref_name,
                                const gchar *icon_name,
@@ -232,6 +233,46 @@ gnc_tree_view_add_date_column (GncTreeView *view,
                                gint model_visibility_column,
                                GtkTreeIterCompareFunc column_sort_fn);
 
+/** This function adds a pixbuf view column to a GncTreeView base view.
+ *  It takes all the parameters necessary to hook a GtkTreeModel
+ *  column to a GtkTreeViewColumn.
+ *
+ *  @param view A pointer to a generic GncTreeView.
+ *
+ *  @param column_title The title for this column.
+ *
+ *  @param pref_name The internal name of this column.  This name is
+ *  used in several functions to look up the column, and it is also
+ *  used when saving/restoring the view's state.
+ *
+ *  @param sizing_text A string used to compute the default width of
+ *  the column.  This text is never displayed.
+ *
+ *  @param model_data_column The index of the GtkTreeModel data column
+ *  used to determine the data that will be displayed in this column
+ *  for each row in the view.  Use GNC_TREE_VIEW_COLUMN_DATA_NONE if
+ *  you plan on using a non-model data source for this column.  This
+ *  index is connected to the "icon-name" attribute of the cell renderer.
+ *
+ *  @param model_visibility_column The index of the GtkTreeModel data
+ *  column used to determine whether or not a checkbox for each row
+ *  will be displayed at all.  Use GNC_TREE_VIEW_COLUMN_VISIBLE_ALWAYS
+ *  if the checkbox should be displayed in all rows.
+ *
+ *  @param column_sort_fn The function that GtkTreeModelSort
+ *  will call to compare two rows to determine their displayed
+ *  order.
+ *
+ *  @return The newly created GtkTreeViewColumn.
+ */
+GtkTreeViewColumn *
+gnc_tree_view_add_pix_column (GncTreeView *view,
+                              const gchar *column_title,
+                              const gchar *pref_name,
+                              const gchar *sizing_text,
+                              gint model_data_column,
+                              gint model_visibility_column,
+                              GtkTreeIterCompareFunc column_sort_fn);
 
 /** This function adds a new numeric column to a GncTreeView base
  *  view.  It takes all the parameters necessary to hook a
@@ -438,7 +479,7 @@ gnc_tree_view_get_show_column_menu (GncTreeView *view);
  *  @returns The cell renderer in use in the column.
  */
 GtkCellRenderer *
-gnc_tree_view_column_get_renderer(GtkTreeViewColumn *column);
+gnc_tree_view_column_get_renderer (GtkTreeViewColumn *column);
 
 
 /* Takes a GdkEventKey and the current path and column for the
@@ -446,12 +487,26 @@ gnc_tree_view_column_get_renderer(GtkTreeViewColumn *column);
  * cursor.  Returns the new column and the possibly changed (if
  * navigation wrapped a row) path. */
 void
-gnc_tree_view_keynav(GncTreeView *view, GtkTreeViewColumn **col,
-                     GtkTreePath *path, GdkEventKey *event);
+gnc_tree_view_keynav (GncTreeView *view, GtkTreeViewColumn **col,
+                      GtkTreePath *path, GdkEventKey *event);
 
-/* Returns TRUE if path is a vaid path for the treeview */
+/* Returns TRUE if path is a valid path for the treeview */
 gboolean
-gnc_tree_view_path_is_valid(GncTreeView *view, GtkTreePath *path);
+gnc_tree_view_path_is_valid (GncTreeView *view, GtkTreePath *path);
+
+/** Setup a callback for when the user starts editing so appropriate actions can be taken
+ *  like disable the actions delete menu option.
+ */
+void
+gnc_tree_view_set_editing_started_cb (GncTreeView *view,
+                     GFunc editing_started_cb, gpointer editing_cb_data);
+
+/** Setup a callback for when the user finishes editing so appropriate actions can be taken
+ *  like enable the actions delete menu option.
+ */
+void
+gnc_tree_view_set_editing_finished_cb (GncTreeView *view,
+                    GFunc editing_finished_cb, gpointer editing_cb_data);
 
 /** @} */
 
